=======
DONATE!
=======

.. _BitCoins: https://en.wikipedia.org/wiki/Bitcoin
.. _4A86FE43: http://pgp.rediris.es:11371/pks/lookup?search=0x4A86FE43&op=vindex&fingerprint=on&exact=on

Work on this project is currently driven by my own interests, needs and
spare time. If you appreciate this software or if you want to sponsor a
currently not translated API feature, please consider donation to the
project.

Python Berkeley DB bindings needs your help.

You can donate using BitCoins_. The destination address is
16avqyUK4vDqBdpUy365PPW44zNqVHLZSC.

.. image:: bitcoin.png
   :align: center
   :alt: 16avqyUK4vDqBdpUy365PPW44zNqVHLZSC.

Since donations thru BitCoin are not revocable, please be sure your are
transfering to the right account (this document could have been modified
for a third party). You can verify it in two diffent ways:

1. Reading this document in the project original website:
   `https://docs.jcea.es/berkeleydb/latest/donate.html
   <https://docs.jcea.es/berkeleydb/latest/donate.html>`__. Make
   sure you are seeing the right webpage.

2. Verifying the PGP digital signature of the following document:

   .. code-block:: none

     -----BEGIN PGP SIGNED MESSAGE-----
     Hash: SHA256

     The BitCoin address for donations to
     PyBSDDB/BSDDB3/BERKELEYDB project
     is "16avqyUK4vDqBdpUy365PPW44zNqVHLZSC".

     -----BEGIN PGP SIGNATURE-----
     
     iQEzBAEBCAAdFiEEjwz+sGozagScNtuNaOA3rUqG/kMFAl+2584ACgkQaOA3rUqG
     /kPqOwgAj4HwcPPVT2nwjwR6+jlCRvz1Qkn4HWXyQmUifcaWfYcX2yxw1AK8EJfI
     u84xBgdLjsrNZLra5BJ+VKvVEHLjm72/avsBB77Wt7ZmipQAoseTTyUoIPwSbznS
     UenkLLYoXGJ8P+cR3VLS06e8BmDiL7H//yNrdC5B/jWl3vgyPmOsUCUuTty/cOq4
     Xqo/N/RyUeoqprQcxw+pKkNyTyfPt4NW3bwdDPJc6Sc8svaDNQiqwtP4di0/zSrT
     rsbH6hpmPytqURUD/foapkxI9tDGgRK8AB1x7aRAc0VnhB8JS0E0jY7yU+iq/dT2
     NMbJH8p5YWsQTZax8HHqRjm7xm8xfg==
     =tyk9
     -----END PGP SIGNATURE-----

   Doing something like :kbd:`gpg --verify` and pasting this block, your
   should get something like:

   .. code-block:: none

      gpg: Signature made Wed 23 Jul 2014 08:44:59 PM CEST using RSA key ID 4A86FE43
      gpg: Good signature from "Jesús Cea Avión <jcea@jcea.es>"

   My PGP key ID is "4A86FE43_". My key fingerprint is::

    pub   4096R/1567BC0F 2014-01-13
          Key fingerprint = 8627 62C4 6EC3 567C B58C  7FB1 A510 404E 1567 BC0F
	  uid                  Jesús Cea Avión <jcea@jcea.es>
	  sub   2048R/4A86FE43 2014-01-13
	  sub   2048R/05488493 2014-01-13

